summaryrefslogtreecommitdiff
path: root/Build/source/libs/icu-xetex/layout/LEGlyphStorage.h
diff options
context:
space:
mode:
Diffstat (limited to 'Build/source/libs/icu-xetex/layout/LEGlyphStorage.h')
-rw-r--r--Build/source/libs/icu-xetex/layout/LEGlyphStorage.h15
1 files changed, 9 insertions, 6 deletions
diff --git a/Build/source/libs/icu-xetex/layout/LEGlyphStorage.h b/Build/source/libs/icu-xetex/layout/LEGlyphStorage.h
index 845ff12146f..34e3f3df93b 100644
--- a/Build/source/libs/icu-xetex/layout/LEGlyphStorage.h
+++ b/Build/source/libs/icu-xetex/layout/LEGlyphStorage.h
@@ -63,11 +63,12 @@ private:
float *fPositions;
/**
- * The auxillary data array.
+ * The auxiliary data arrays.
*
* @internal
*/
void **fAuxData;
+ void **fAuxParam;
/**
@@ -295,6 +296,7 @@ public:
* @draft ICU 3.0
*/
void *getAuxData(le_int32 glyphIndex, LEErrorCode &success) const;
+ void *getAuxData2(le_int32 glyphIndex, LEErrorCode &success) const;
/**
* This operator allows direct access to the glyph array
@@ -387,15 +389,16 @@ public:
void adjustPosition(le_int32 glyphIndex, float xAdjust, float yAdjust, LEErrorCode &success);
/**
- * Set the auxillary data for a particular glyph.
+ * Set the auxiliary data for a particular glyph.
*
* @param glyphIndex the index of the glyph
* @param auxData the new auxillary data
* @param success will be set to an error code if the auxillary data cannot be set.
*
* @draft ICU 3.0
*/
- void setAuxData(le_int32 glyphIndex, void *auxData, LEErrorCode &success);
+ void setAuxData(le_int32 glyphIndex, void *auxData, void *auxParam, LEErrorCode &success);
/**
* Delete the glyph array and replace it with the one
@@ -443,7 +446,7 @@ public:
*
* @draft ICU 3.0
*/
- void adoptAuxDataArray(LEGlyphStorage &from);
+ void adoptAuxDataArrays(LEGlyphStorage &from);
/**
* Change the glyph count of this object to be the same
@@ -387,15 +389,16 @@ public:
*
* @param glyphIndex the index of the glyph
- * @param auxData the new auxillary data
- * @param success will be set to an error code if the auxillary data cannot be set.
+ * @param auxData the new auxiliary data
+ * @param auxParam the new secondary auxiliary data (parameter)
+ * @param success will be set to an error code if the auxiliary data cannot be set.
*
* @draft ICU 3.0